==> monodevelop_2.8.6.3%2Bdfsg.orig.tar.gz: monodevelop-2.8.6.3/src/addins/MonoDevelop.MacDev/XcodeSyncing/XcodeSyncContext.cs <==
// 
// XcodeSyncContext.cs
//  
// Author:
//       Michael Hutchinson <mhutch@xamarin.com>
// 
// Copyright (c) 2011 Xamarin, Inc (http://xamarin.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Linq;
using System.IO;
using System.Collections.Generic;

using MonoDevelop.Core;
using MonoDevelop.Projects;
using MonoDevelop.MacDev.ObjCIntegration;
using System.Threading.Tasks;
using MonoDevelop.MacDev.XcodeIntegration;

namespace MonoDevelop.MacDev.XcodeSyncing
{
	class XcodeSyncContext
	{
		Dictionary<string,DateTime> syncTimes;
		
		public XcodeSyncContext (FilePath projectDir, Dictionary<string,DateTime> syncTimes)
		{
			this.ProjectDir = projectDir;
			this.syncTimes = syncTimes;
		}
		
		public FilePath ProjectDir { get; set; }
		
		public DateTime GetSyncTime (string relativeFilename)
		{
			DateTime value;
			if (!syncTimes.TryGetValue (relativeFilename, out value)) {
				value = File.GetLastWriteTime (ProjectDir.Combine (relativeFilename));
				syncTimes[relativeFilename] = value;
			}
			return value;
		}
		
		public void UpdateSyncTime (string relativeFilename)
		{
			syncTimes[relativeFilename] = File.GetLastWriteTime (ProjectDir.Combine (relativeFilename));
		}
		
		public void SetSyncTimeToNow (string relativeFilename)
		{
			syncTimes[relativeFilename] = DateTime.Now;
		}
	}
}

==> monodevelop_3.0.2%2Bdfsg.orig.tar.gz: monodevelop-3.0.2/src/addins/MonoDevelop.MacDev/XcodeSyncing/XcodeSyncContext.cs <==
// 
// XcodeSyncContext.cs
//  
// Author:
//       Michael Hutchinson <mhutch@xamarin.com>
// 
// Copyright (c) 2011 Xamarin, Inc (http://xamarin.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Linq;
using System.IO;
using System.Collections.Generic;

using MonoDevelop.Core;
using MonoDevelop.Projects;
using MonoDevelop.MacDev.ObjCIntegration;
using System.Threading.Tasks;
using MonoDevelop.MacDev.XcodeIntegration;

namespace MonoDevelop.MacDev.XcodeSyncing
{
	class XcodeSyncContext
	{
		Dictionary<string,DateTime> syncTimes;
		
		public XcodeSyncContext (FilePath projectDir, Dictionary<string,DateTime> syncTimes)
		{
			this.ProjectDir = projectDir;
			this.syncTimes = syncTimes;
		}
		
		public FilePath ProjectDir { get; set; }
		
		public DateTime GetSyncTime (string relativeFilename)
		{
			DateTime mtime;
			
			if (!syncTimes.TryGetValue (relativeFilename, out mtime)) {
				mtime = File.GetLastWriteTime (ProjectDir.Combine (relativeFilename));
				syncTimes[relativeFilename] = mtime;
			}
			
			return mtime;
		}
		
		public void SetSyncTime (string relativeFilename, DateTime mtime)
		{
			syncTimes[relativeFilename] = mtime;
		}
	}
}
